import { Component } from '@angular/core';
import { Platform } from 'ionic-angular';
import { StatusBar } from '@ionic-native/status-bar';
import { SplashScreen } from '@ionic-native/splash-screen';

import { LoginPage } from '../pages/login/login';
import { TabsPage } from '../pages/tabs/tabs';
import { Storage } from '@ionic/storage';
import { FCM } from "@ionic-native/fcm";
import { Functions } from '../providers/functions';

@Component({
  templateUrl: 'app.html'
})
export class MyApp {
  rootPage:any;

  constructor(platform: Platform,
              statusBar: StatusBar,
              splashScreen: SplashScreen,
              storage: Storage,
              commonFunction: Functions,
              public fcm: FCM) {

    platform.ready().then(() => {
      // Okay, so the platform is ready and our plugins are available.
      // Here you can do any higher level native things you might need.
      statusBar.styleDefault();
      splashScreen.hide();

      // Check if user is logged in -> skip login
      storage.ready().then(() => {
        storage.get("userIsLogin").then((userIsLogged) => {
          if (userIsLogged) {
                  this.rootPage = TabsPage;
          } else  this.rootPage = LoginPage;
        });
      });

      /**
       * MANAGEMENT OF NOTIFICATIONS WITH FIREBASE 
       */

      // Get and register Firebase token
      this.fcm.getToken()
        .then((token:string) => {
         // Here we could register token to server if we want to send unique message to this device
        })
        .catch(error => {
          console.error(error);
        });
      // Subscribe to new token refresh
      this.fcm.onTokenRefresh().subscribe((token:string) => {
        }, error => {
          console.error(error);
        }
      );
      // Notification received
      this.fcm.onNotification().subscribe((data) => {
          if (data.wasTapped) {
            // App is in background, received in status bar, do nothing
          } else {
            // App is in foreground, show notification with alert message
            let title = data.title;
            let message = data.body;
            let button = "D'acord";
            commonFunction.showAlert(title,message,button);
          }
         }, error => {
          console.error("Error in notification",error)
         }
      );

    });
  }

}
