import { Component } from '@angular/core';
import { PopoverController, App, Tabs } from 'ionic-angular';
import { StatusBar } from '@ionic-native/status-bar';

import { UrgenciesServicesProvider } from '../../providers/apiServices/urg.services';
import { HospitalServicesProvider } from '../../providers/apiServices/hos.services';
import { Functions } from '../../providers/functions';

import { PopmenuPage } from '../popmenu/popmenu';

@Component({
  selector: 'page-home',
  templateUrl: 'home.html'
})

export class HomePage {
  
  /*Urgencies variables*/
  iniUrgencies : any = [];
  iniHospital : any = [];
  /*Hospital variables*/
  pcntOcupats : any = 0;
  lliures_NORES : any = 0;
  lliures_RES : any = 0;
  ocupats_NORES : any = 0;
  ocupats_RES : any = 0;
  ocupats : any = 0;
  lliures : any = 0;
  reservats : any = 0;
  iniHospitalAltes : any = [];
  iniAltes : any = 0;
  radius : any = 60;
  circleAbs : any = this.radius*2*3.1415;

  month = this.commonFunction.getMonth();

  // Assign popover menu
  popover = this.popCtrl.create(PopmenuPage);

  // To use for programatically change active tab by clicking card
  tabsNav = this.app.getNavByIdOrName('mainNav') as Tabs;

  constructor(public urgServices: UrgenciesServicesProvider,
              public hosServices: HospitalServicesProvider,
              public commonFunction: Functions,
              public popCtrl: PopoverController,
              private app: App,
              private statusBar: StatusBar) {
  }

  ionViewWillEnter() {

    // Check if user is logged in
    this.commonFunction.checkLogin();

    // Status bar color
    this.statusBar.styleLightContent();
    this.statusBar.backgroundColorByHexString('#0086c3');

    this.circleAbs = this.radius*2*3.1415;
    this.commonFunction.showLoading();
    this.getUrgHomeData();
    this.getHosHomeData();
  }

  getUrgHomeData(){
    this.urgServices.getHomeData().subscribe(res => {
      this.commonFunction.dismissLoading();
      this.iniUrgencies = res[0];
    }, error =>
    {
      this.commonFunction.dismissLoading();
      this.commonFunction.showToast();
    });
  }

  getHosHomeData() {
    this.hosServices.getHomeData().subscribe(res => {
      this.commonFunction.dismissLoading();
      this.iniHospital = res;

      for (let i=0; i<this.iniHospital.length; i++) {
        switch ( this.iniHospital[i].ESTAT ) {
          case 'LIB_NORES' : this.lliures_NORES = parseInt(this.iniHospital[i].RECOMPTE);
          case 'LIB_RES' : this.lliures_RES = parseInt(this.iniHospital[i].RECOMPTE);
          case 'OCU_NORES' : this.ocupats_NORES = parseInt(this.iniHospital[i].RECOMPTE);
          case 'OCU_RES' : this.ocupats_RES = parseInt(this.iniHospital[i].RECOMPTE);
        }
      }

      this.ocupats = this.ocupats_NORES + this.ocupats_RES;
			this.lliures = this.lliures_NORES + this.lliures_RES;
      this.reservats = this.lliures_RES + this.ocupats_RES;
      this.pcntOcupats = this.commonFunction.setPercentage (this.ocupats,this.lliures);
      
      // Calculate circle stroke
      let initCircleAbs = this.radius*2*3.1415;
      this.circleAbs = this.commonFunction.getCircleStroke (initCircleAbs,this.pcntOcupats);

    }, error =>
    {
      this.commonFunction.dismissLoading();
      this.commonFunction.showToast();
    });

    this.hosServices.getTabAltesData().subscribe(res => {
      this.commonFunction.dismissLoading();
      this.iniHospitalAltes = res;
      this.iniAltes = 0;
      for (let i=0; i<this.iniHospitalAltes.length; i++) {
        this.iniAltes = this.iniAltes + Number(this.iniHospitalAltes[i].NUMALTES);
      }
      this.iniAltes = this.commonFunction.setThousands(this.iniAltes);
    }, error =>
    {
      this.commonFunction.dismissLoading();
      this.commonFunction.showToast();
    });
  }

  /* Present popover menu */
  presentPopMenu(event) {
    this.popover.present({
      ev: event
    });
  }

  /* Change active tab by clicking on card */
  goToUrgenciesTab() {
    this.tabsNav.select(1);
  }
  goToHospitalTab() {
    this.tabsNav.select(2);
  }

}
