import { Component } from '@angular/core';
import { LoadingController, IonicPage, NavController, NavParams, Events } from 'ionic-angular';

import { HospitalServicesProvider } from '../../providers/apiServices/hos.services';
import { Functions } from '../../providers/functions';

/**
 * Generated class for the HospitalAltesPage page.
 *
 * See https://ionicframework.com/docs/components/#navigation for more info on
 * Ionic pages and navigation.
 */

@IonicPage()
@Component({
  selector: 'page-hospital-altes',
  templateUrl: 'hospital-altes.html',
})
export class HospitalAltesPage {

  animation : boolean = false;
  hosAltesData : any = [];
  hosAltesTotal : any = 0;
  monthShort : string = this.commonFunction.getMonthShort();

  constructor(public navCtrl: NavController,
              public navParams: NavParams,
              public loadingCtrl: LoadingController,
              public hosServices: HospitalServicesProvider,
              public commonFunction: Functions,
              public events: Events) {
                
    this.events.subscribe('functionCall:refreshHospital', eventData => { 
      this.ionViewWillEnter();
    });

  }

  ionViewWillEnter() {
    this.hosAltesTotal = 0;
    this.animation = false;
    this.commonFunction.showLoading();
    this.getAltesData();
  }

  getAltesData() {
    this.hosServices.getTabAltesData().subscribe(res => {
      this.commonFunction.dismissLoading();
      this.hosAltesData = res;
      /* max number of patients given alta for service, it's always the first [0] */
      let maxvalue = this.hosAltesData[0].NUMALTES;
        for (let i=0; i<this.hosAltesData.length; i++) {
          this.hosAltesTotal += Number(this.hosAltesData[i].NUMALTES);
          /* Add value of width in res object for the coloured bar under each service, based on max value of patients */
          this.hosAltesData[i].WIDTH = ((Number(this.hosAltesData[i].NUMALTES) * 100)/maxvalue)+"%";
        }
        this.hosAltesTotal = this.commonFunction.setThousands(this.hosAltesTotal);
        /* animate white bar to show coloured bar */
        setTimeout(() => {
          this.animation = true;
        }, 200);
    }, error =>
    {
      this.commonFunction.dismissLoading();
      this.commonFunction.showToast();
    });
  }

  showInfoAltes(){
    let month = this.commonFunction.getMonth();
    if(month.startsWith("a") || month.startsWith("o")){
      month = "d'"+month;
    } else month = "de "+month;
    let day = this.commonFunction.getDay();
    let title = "Altes per serveis i unitats";
    let message = "Altes donades des del dia 1 al "+day+" "+month+", organitzades per serveis i unitats.";
    let button = "D'acord";
    this.commonFunction.showAlert(title,message,button);
  }

}
