import { Component } from '@angular/core';
import { LoadingController, IonicPage, NavController, NavParams, Events } from 'ionic-angular';

import { HospitalServicesProvider } from '../../providers/apiServices/hos.services';
import { Functions } from '../../providers/functions';

/**
 * Generated class for the HospitalOcupacioPage page.
 *
 * See https://ionicframework.com/docs/components/#navigation for more info on
 * Ionic pages and navigation.
 */

@IonicPage()
@Component({
  selector: 'page-hospital-ocupacio',
  templateUrl: 'hospital-ocupacio.html',
})
export class HospitalOcupacioPage {

  hosOcupacioData : any = [];
  /* Defition of variables that will be used in html view */
  adultsOCU = 0;
  adultsLIB = 0;
  adultsRES = 0;
  pediatriaOCU = 0;
  pediatriaLIB = 0;
  pediatriaRES = 0;
  salutMentalOCU = 0;
  salutMentalLIB = 0;
  salutMentalRES = 0;
  sociosanitariOCU = 0;
  sociosanitariLIB = 0;
  sociosanitariRES = 0;
  totalOCU = 0;
  totalLIB = 0;
  totalRES = 0;
  adultsPctOCU = 0;	
  pediatriaPctOCU = 0;
  salutMentalPctOCU = 0;
  sociosanitariPctOCU = 0;
  totalPctOCU = 0;

  radius : any = 85;
  circleAbs : any = this.radius*2*3.1415;

  constructor(public navCtrl: NavController,
              public navParams: NavParams,
              public loadingCtrl: LoadingController,
              public hosServices: HospitalServicesProvider,
              public commonFunction: Functions,
              public events: Events) {
                
    this.events.subscribe('functionCall:refreshHospital', eventData => { 
      this.ionViewWillEnter();
    });
    
  }

  ionViewWillEnter() {
    this.commonFunction.showLoading();
    this.circleAbs = this.radius*2*3.1415;
    this.getOcupacioData();
  }

  getOcupacioData() {
    this.hosServices.getTabOcupacioData().subscribe(res => {
      this.hosOcupacioData = res;

      /*Variables for every zone (adults, pediatria, salut mental and sociosanitari) and all possibilities for beds:
      lliures no reservats, lliures reservats, ocupats no reservats, ocupats reservats*/
      let adultsLIB_NORES        = 0; let adultsLIB_RES         = 0; let adultsOCU_NORES        = 0; let adultsOCU_RES        = 0;
      let pediatriaLIB_NORES 	   = 0; let pediatriaLIB_RES 	    = 0; let pediatriaOCU_NORES     = 0; let pediatriaOCU_RES     = 0;
      let salutMentalLIB_NORES   = 0; let salutMentalLIB_RES    = 0; let salutMentalOCU_NORES   = 0; let salutMentalOCU_RES   = 0;
      let sociosanitariLIB_NORES = 0; let sociosanitariLIB_RES  = 0; let sociosanitariOCU_NORES = 0; let sociosanitariOCU_RES = 0;
      
      let totalLIB_NORES         = 0; let totalLIB_RES          = 0; let totalOCU_NORES         = 0; let totalOCU_RES         = 0;

		  let actualCount  = 0;

      for (let i=0; i<this.hosOcupacioData.length; i++) {
        actualCount = parseInt(this.hosOcupacioData[i].RECOMPTE);
        switch ( this.hosOcupacioData[i].SITE ) {
          case 'HPT':
            if( this.hosOcupacioData[i].SERVEI == 'TRP' ){
              switch ( this.hosOcupacioData[i].ESTAT ) {
                case "LIB_NORES": pediatriaLIB_NORES += actualCount; break;
								case "LIB_RES":   pediatriaLIB_RES   += actualCount; break;
								case "OCU_NORES": pediatriaOCU_NORES += actualCount; break;
								case "OCU_RES":   pediatriaOCU_RES   += actualCount; break;
              }
            } else {
							switch ( this.hosOcupacioData[i].ESTAT ){
								case "LIB_NORES": adultsLIB_NORES += actualCount; break;
								case "LIB_RES":   adultsLIB_RES   += actualCount; break;
								case "OCU_NORES": adultsOCU_NORES += actualCount; break;
								case "OCU_RES":   adultsOCU_RES   += actualCount; break;
							}                                                        
						} break;
          case 'ALB':
            switch ( this.hosOcupacioData[i].ESTAT ){
              case "LIB_NORES": sociosanitariLIB_NORES += actualCount; break;
              case "LIB_RES":   sociosanitariLIB_RES   += actualCount; break;
              case "OCU_NORES": sociosanitariOCU_NORES += actualCount; break;
              case "OCU_RES":   sociosanitariOCU_RES   += actualCount; break;
            } break;
          case 'CSM':
            if( this.hosOcupacioData[i].SERVEI=="UCA" ){
              switch ( this.hosOcupacioData[i].ESTAT ){
                case "LIB_NORES": pediatriaLIB_NORES += actualCount; break;
                case "LIB_RES":   pediatriaLIB_RES   += actualCount; break;
                case "OCU_NORES": pediatriaOCU_NORES += actualCount; break;
                case "OCU_RES":   pediatriaOCU_RES   += actualCount; break;
              }                           
            } else {
              switch ( this.hosOcupacioData[i].ESTAT ){
                case "LIB_NORES": salutMentalLIB_NORES += actualCount; break;
                case "LIB_RES":   salutMentalLIB_RES   += actualCount; break;
                case "OCU_NORES": salutMentalOCU_NORES += actualCount; break;
                case "OCU_RES":   salutMentalOCU_RES   += actualCount; break;
              }                                                       
            } break;
        };
        switch ( this.hosOcupacioData[i].ESTAT ){
          case "LIB_NORES": totalLIB_NORES += actualCount; break;
          case "LIB_RES":   totalLIB_RES   += actualCount; break;
          case "OCU_NORES": totalOCU_NORES += actualCount; break;
          case "OCU_RES":   totalOCU_RES   += actualCount; break;
        };  
      }

      // Calculate absolute values of beds
      this.adultsOCU 		 = adultsOCU_NORES + adultsOCU_RES; 
      this.adultsLIB 		 = adultsLIB_NORES + adultsLIB_RES; 
      this.adultsRES 		 = adultsLIB_RES   + adultsOCU_RES; 
  
      this.pediatriaOCU 	 = pediatriaOCU_NORES + pediatriaOCU_RES;
      this.pediatriaLIB 	 = pediatriaLIB_NORES + pediatriaLIB_RES;
      this.pediatriaRES 	 = pediatriaLIB_RES   + pediatriaOCU_RES;
  
      this.salutMentalOCU 	 = salutMentalOCU_NORES + salutMentalOCU_RES;
      this.salutMentalLIB 	 = salutMentalLIB_NORES + salutMentalLIB_RES;
      this.salutMentalRES 	 = salutMentalLIB_RES   + salutMentalOCU_RES;
  
      this.sociosanitariOCU = sociosanitariOCU_NORES + sociosanitariOCU_RES;
      this.sociosanitariLIB = sociosanitariLIB_NORES + sociosanitariLIB_RES;
      this.sociosanitariRES = sociosanitariLIB_RES   + sociosanitariOCU_RES;
    
      this.totalOCU 		 = totalOCU_NORES + totalOCU_RES;
      this.totalLIB 		 = totalLIB_NORES + totalLIB_RES;
      this.totalRES 		 = totalLIB_RES   + totalOCU_RES;
      
      // Calculate percentage values of beds
      this.adultsPctOCU 		= this.commonFunction.setPercentage (this.adultsOCU,this.adultsLIB);		
      this.pediatriaPctOCU 	= this.commonFunction.setPercentage (this.pediatriaOCU,this.pediatriaLIB);
      this.salutMentalPctOCU 	= this.commonFunction.setPercentage (this.salutMentalOCU,this.salutMentalLIB);
      this.sociosanitariPctOCU = this.commonFunction.setPercentage (this.sociosanitariOCU,this.sociosanitariLIB);
      this.totalPctOCU 		= this.commonFunction.setPercentage (this.totalOCU,this.totalLIB);

      // Calculate circle stroke
      let initCircleAbs = this.radius*2*3.1415;
      this.circleAbs = this.commonFunction.getCircleStroke(initCircleAbs,this.totalPctOCU);

      this.commonFunction.dismissLoading();

    }, error =>
    {
      this.commonFunction.dismissLoading();
      this.commonFunction.showToast();
    });
  }

  showInfoOcupacio(){
    let title = "Ocupació hospitalària";
    let message = "Llits ocupats, reservats i lliures que hi ha ara mateix a hospitalització, tant en general com per àrees. Consideracions:<br>- Llits ocupats = ocupats no reservats + ocupats reservats.<br>- Llits lliures = lliures no reservats + lliures reservats.<br>- Llits reservats = ocupats reservats + lliures reservats.<br>- Llits totals = ocupats + lliures.";
    let button = "D'acord";
    this.commonFunction.showAlert(title,message,button);
  }

}
