import { Component } from '@angular/core';
import { IonicPage, NavController, NavParams } from 'ionic-angular';
import { FormGroup, FormBuilder, Validators } from '@angular/forms';
import { Storage } from '@ionic/storage';
import { StatusBar } from '@ionic-native/status-bar';

import { AuthProvider } from '../../providers/apiServices/auth';
import { Functions } from '../../providers/functions';

import { TabsPage } from '../tabs/tabs';

/**
 * Generated class for the LoginPage page.
 *
 * See https://ionicframework.com/docs/components/#navigation for more info on
 * Ionic pages and navigation.
 */

@IonicPage()
@Component({
  selector: 'page-login',
  templateUrl: 'login.html',
})
export class LoginPage {

  private loginData : FormGroup;
  private username: any;
  private password: any;
  private rememberLogin: boolean = false;
  loginResponse : any;

  constructor(public navCtrl: NavController,
              public navParams: NavParams,
              public formBuilder: FormBuilder,
              public authProvider: AuthProvider,
              public commonFunction: Functions,
              public storage: Storage,
              private statusBar: StatusBar) {
      
    this.loginData = this.formBuilder.group({
      username: ['', Validators.required],
      password: [''],
      rememberLogin: ['']
    });

  }

  ionViewWillEnter() {
    // Status bar color
    this.statusBar.styleLightContent();
    this.statusBar.backgroundColorByHexString('#039be5');

    // Check if login data must be remembered
    this.storage.ready().then(() => {
      this.storage.get("infoLogin").then((storedLogin) => {
        if(storedLogin != null) { 
          this.rememberLogin = true;
          let login = JSON.parse(storedLogin);
          this.username = login.usuari;
          this.password = login.contrasenya;
        }
      });
    });
  }

  login(){
    this.commonFunction.showLogin();
    this.authProvider.login(this.loginData.value).subscribe(res =>{
      this.loginResponse = res;
      if (this.loginResponse.codi_error == 0) { //login success
        //storage login data
        this.storage.ready().then(() => {
          //check if login data must be stored
          if(this.rememberLogin) {
            this.storage.set("infoLogin", JSON.stringify({usuari:this.username,contrasenya:this.password}));
          } else {
            this.storage.remove("infoLogin");
          }
          //leave user logged in when reload
          this.storage.set("userIsLogin", true);
        });
        this.commonFunction.dismissLogin();
        this.navCtrl.setRoot(TabsPage);
      } else if (this.loginResponse.codi_error == 1) { //login fail
        let message = this.loginResponse.desc_error;
        this.showErrorLogin(message);
      }
    }, error =>
    {
      this.commonFunction.dismissLogin();
      this.commonFunction.showToast();
    }
  )};

  showErrorLogin(msg){
    let title = "Error";
    let button = "D'acord";
    this.commonFunction.showAlert(title,msg,button);
  }

}
