import { Component } from '@angular/core';
import { LoadingController, IonicPage, NavController, NavParams, Events } from 'ionic-angular';

import { UrgenciesServicesProvider } from '../../providers/apiServices/urg.services';
import { Functions } from '../../providers/functions';

/**
 * Generated class for the UrgenciesIngressarPage page.
 *
 * See https://ionicframework.com/docs/components/#navigation for more info on
 * Ionic pages and navigation.
 */

@IonicPage()
@Component({
  selector: 'page-urgencies-ingressar',
  templateUrl: 'urgencies-ingressar.html',
})
export class UrgenciesIngressarPage {

  urgIngressarData : any = [];
  urgLlitsData : any = [];
  urgAltesTotal : any = 0;
  urgLlitsTotal : any = 0;
  iniUrgencies : any = [];
  animation = false;

  constructor(public navCtrl: NavController,
              public navParams: NavParams,
              public loadingCtrl: LoadingController,
              public urgServices: UrgenciesServicesProvider,
              public commonFunction: Functions,
              public events: Events) {

    // Subscribe to refresh event
    this.events.subscribe('functionCall:refreshUrgencies', eventData => { 
      this.ionViewWillEnter();
    });

  }

  ionViewWillEnter() {
    this.animation = false;
    this.commonFunction.showLoading();
    this.getIngressarData();
    this.getHomeData();
    this.getLlitsData();
  }

  getIngressarData() {
    this.urgServices.getTabIngressarData().subscribe(res => {
      this.commonFunction.dismissLoading();
      this.urgIngressarData = res;
      /* max number of patients waiting for one service, it's always the first [0] */
      let maxvalue = this.urgIngressarData[0].NUM;
        for (let i=0; i<this.urgIngressarData.length; i++) {
          /* Add value of width in res object for the coloured bar under each service, based on max value of patients */
          this.urgIngressarData[i].WIDTH = ((Number(this.urgIngressarData[i].NUM) * 100)/maxvalue)+"%";
        }
        /* animate white bar to show coloured bar */
        setTimeout(() => {
          this.animation = true;
        }, 200);

    }, error =>
    {
      this.commonFunction.dismissLoading();
      this.commonFunction.showToast();
    });
  }

  getLlitsData(){
    this.urgServices.getTabLlitsData().subscribe(res => {
      this.urgLlitsData = res;
      /*get total llits, each loop means +1 llit*/
      this.urgLlitsTotal = 0;
      for (let i=0; i<this.urgLlitsData.length; i++) {
        this.urgLlitsTotal += 1;
      }
    }, error =>
    {
      this.commonFunction.dismissLoading();
      this.commonFunction.showToast();
    });
  }

  getHomeData(){
    this.urgServices.getHomeData().subscribe(res => {
      this.iniUrgencies = res[0];
    }, error =>
    {
      this.commonFunction.dismissLoading();
      this.commonFunction.showToast();
    });
  }

  showInfoIngressos(){
    let title = "Altes pendents d'ingrés per serveis";
    let message = "Pacients que hi ha ara mateix que han estat donats d'alta d'urgències i estan esperant habitació per ser hospitalitzats, sense llit reservat. Es mostren organitzats per serveis.";
    let button = "D'acord";
    this.commonFunction.showAlert(title,message,button);
  }

  showInfoLlits(){
    let title = "Llits lliures no reservats";
    let message = "Llits disponibles (lliures no reservats) ara mateix a hospitalització. Si el llit del costat està ocupat, s'indica el sexe i l'edat del pacient.";
    let button = "D'acord";
    this.commonFunction.showAlert(title,message,button);
  }

}
