import { Component } from '@angular/core';
import { LoadingController, IonicPage, NavController, NavParams, Events } from 'ionic-angular';

import { UrgenciesServicesProvider } from '../../providers/apiServices/urg.services';
import { Functions } from '../../providers/functions';

/**
 * Generated class for the UrgenciesZonesPage page.
 *
 * See https://ionicframework.com/docs/components/#navigation for more info on
 * Ionic pages and navigation.
 */

@IonicPage()
@Component({
  selector: 'page-urgencies-zones',
  templateUrl: 'urgencies-zones.html',
})
export class UrgenciesZonesPage {

  areesNames = [
    {
      short: 'CGURG',
      long: 'Cirurgia General'
    },
    {
      short: 'GOURG',
      long: 'Ginecologia i Obstetrícia'
    },
    {
      short: 'MDURG',
      long: 'Medicina General'
    },
    {
      short: 'MPURG',
      long: 'Medicina Pediàtrica'
    },
    {
      short: 'PSURG',
      long: 'Psiquiatria'
    },
    {
      short: 'TOURG',
      long: 'Traumatologia i Ortopèdia'
    },
    {
      short: 'Totes',
      long: 'Totes'
    },
  ];
  areaActive = 0;
  animation = false;
  urgZonesData : any = [];
  urgEpisodisActius;
  urgAreesData = [
    {
      nom: this.areesNames[0].long,
      episodistotal: 0,
      nivell: []
    },
    {
      nom: this.areesNames[1].long,
      episodistotal: 0,
      nivell: []
    },
    {
      nom: this.areesNames[2].long,
      episodistotal: 0,
      nivell: []
    },
    {
      nom: this.areesNames[3].long,
      episodistotal: 0,
      nivell: []
    },
    {
      nom: this.areesNames[4].long,
      episodistotal: 0,
      nivell: []
    },
    {
      nom: this.areesNames[5].long,
      episodistotal: 0,
      nivell: []
    }
  ];

  constructor(public navCtrl: NavController,
              public navParams: NavParams,
              public loadingCtrl: LoadingController,
              public urgServices: UrgenciesServicesProvider,
              public commonFunction: Functions,
              public events: Events) {

    this.events.subscribe('functionCall:refreshUrgencies', eventData => { 
      this.ionViewWillEnter();
    });

  } 

  ionViewWillEnter() {
    this.animation = false;
    this.urgEpisodisActius = 0;
    this.commonFunction.showLoading();
    this.getAreesData();
    this.getZonesData();
  }

  getAreesData() {
    this.urgServices.getTabAreesData().subscribe(res => {
      this.initializeArraysZones();
      let responseArees = res;
      // once the array this.urgAreesData is initialized, all 'nivells' in each area that contain 'episodis' and 'temps' values are filled
      for (let i=0; i<responseArees.length; i++) {
        let nivellres;
        switch(responseArees[i].AREA){
          case this.areesNames[0].short :
            nivellres = parseInt(responseArees[i].NIVELL) - 1;
            this.urgAreesData[0].nivell[nivellres].episodis = responseArees[i].NUM_EPISODIS;
            this.urgAreesData[0].nivell[nivellres].temps = responseArees[i].TME;
            this.urgAreesData[0].episodistotal += parseInt(responseArees[i].NUM_EPISODIS);
            break;
          case this.areesNames[1].short :
            nivellres = parseInt(responseArees[i].NIVELL) - 1;
            this.urgAreesData[1].nivell[nivellres].episodis = responseArees[i].NUM_EPISODIS;
            this.urgAreesData[1].nivell[nivellres].temps = responseArees[i].TME;
            this.urgAreesData[1].episodistotal += parseInt(responseArees[i].NUM_EPISODIS);
            break;
          case this.areesNames[2].short :
            nivellres = parseInt(responseArees[i].NIVELL) - 1;
            this.urgAreesData[2].nivell[nivellres].episodis = responseArees[i].NUM_EPISODIS;
            this.urgAreesData[2].nivell[nivellres].temps = responseArees[i].TME;
            this.urgAreesData[2].episodistotal += parseInt(responseArees[i].NUM_EPISODIS);
            break;
          case this.areesNames[3].short :
            nivellres = parseInt(responseArees[i].NIVELL) - 1;
            this.urgAreesData[3].nivell[nivellres].episodis = responseArees[i].NUM_EPISODIS;
            this.urgAreesData[3].nivell[nivellres].temps = responseArees[i].TME;
            this.urgAreesData[3].episodistotal += parseInt(responseArees[i].NUM_EPISODIS);
            break;
          case this.areesNames[4].short :
            nivellres = parseInt(responseArees[i].NIVELL) - 1;
            this.urgAreesData[4].nivell[nivellres].episodis = responseArees[i].NUM_EPISODIS;
            this.urgAreesData[4].nivell[nivellres].temps = responseArees[i].TME;
            this.urgAreesData[4].episodistotal += parseInt(responseArees[i].NUM_EPISODIS);
            break;
          case this.areesNames[5].short :
            nivellres = parseInt(responseArees[i].NIVELL) - 1;
            this.urgAreesData[5].nivell[nivellres].episodis = responseArees[i].NUM_EPISODIS;
            this.urgAreesData[5].nivell[nivellres].temps = responseArees[i].TME;
            this.urgAreesData[5].episodistotal += parseInt(responseArees[i].NUM_EPISODIS);
            break;
        }
      }
      //now this.urgAreesData can be looped in html view
      this.commonFunction.dismissLoading();
    }, error =>
    {
      this.commonFunction.dismissLoading();
      this.commonFunction.showToast();
    });
  }

  getZonesData() {
    this.urgServices.getTabZonesData().subscribe(res => {
      this.commonFunction.dismissLoading();
      this.urgZonesData = res;
      /* max number of patients waiting in one zone, it's always the first */
      let maxvalue = this.urgZonesData[0].NUM_EPISODIS;
        for (let i=0; i<this.urgZonesData.length; i++) {
          /* Add value of width in res object for the coloured bar under each zona, based on max value of patients */
          this.urgZonesData[i].WIDTH = ((Number(this.urgZonesData[i].NUM_EPISODIS) * 100)/maxvalue)+"%";
          // calculate total number of episodis
          this.urgEpisodisActius += parseInt(this.urgZonesData[i].NUM_EPISODIS);
        }
        /* animate white bar to show coloured bar */
        setTimeout(() => {
          this.animation = true;
        }, 200);

    }, error =>
    {
      this.commonFunction.dismissLoading();
      this.commonFunction.showToast();
    });
  }

  initializeArraysZones() {
    // JSON response for Arees sends array only for those levels [j] which contain data
    // All levels [j] must be set to zero for each area [i] and then levels with data will be filled in getAreesData()
    for(let i=0; i<=5; i++) {
      this.urgAreesData[i].episodistotal = 0;
      for (let j=0; j<=4; j++){
        this.urgAreesData[i].nivell[j] = 
          {
            episodis: '0',
            temps: '0'
          };
      }
    }
  }

  showArea(index) {
    this.areaActive = index;
  }

  showInfoArees(){
    let title = "Àrees d'atenció: episodis i temps mig";
    let message = "Pacients que han passat avui per Urgències des de les 00 h, i el temps mig d'espera entre el triatge i l'assistència, classificats per les àrees d'atenció i segons els nivells de gravetat.";
    let button = "D'acord";
    this.commonFunction.showAlert(title,message,button);
  }

  showInfoZones(){
    let title = "Zones d'atenció: episodis";
    let message = "Pacients que hi ha ara mateix a urgències, organitzats segons les zones d'atenció.";
    let button = "D'acord";
    this.commonFunction.showAlert(title,message,button);
  }

}
