import { Injectable } from '@angular/core';
import { LoadingController, AlertController, ToastController, App } from 'ionic-angular';
import { Storage } from '@ionic/storage';

import * as moment from 'moment';
import 'moment/locale/ca';
import * as numeral from 'numeral';
import 'numeral/locales/es';
import { LoginPage } from '../pages/login/login';

/*
  Generated class for the Functions.
*/
@Injectable()
export class Functions {

    loading = this.loadingCtrl.create({
        spinner: 'crescent',
        content: 'Carregant dades ...'
    });
    loadingLogin = this.loadingCtrl.create({
        spinner: 'crescent',
        content: 'Iniciant ...'
    });

    constructor(public loadingCtrl: LoadingController,
                public alertCtrl: AlertController,
                public toastCtrl: ToastController,
                public storage: Storage,
                public app: App) {
    }

    checkLogin () {
        this.storage.get("userIsLogin").then((val) => {
            if(!val) { this.app.getRootNav().setRoot(LoginPage); }
        });
    }

    // Get a percentage of one number over another number, with indicated decimals
    getPercentage(smallNumber, bigNumber, decimals){	
        var pct = ((smallNumber/(smallNumber+bigNumber)) * 100);	
            return (this.getRoundNum(pct, decimals));
    }

    // Round a number with the indicated decimals
    getRoundNum(rnum,decimals){
    var newnumber=0;
        if (rnum > 8191 && rnum < 10485) {
            rnum = rnum-5000;
            newnumber = Math.round(rnum*Math.pow(10,decimals))/Math.pow(10,decimals);
            newnumber = newnumber+5000;
        } else {
            newnumber = Math.round(rnum*Math.pow(10,decimals))/Math.pow(10,decimals);
        }
        return newnumber;
    }

    // Convert decimal to number, used for strokeDashoffset svg circle
    getCircleStroke(stroke,prct){
        return (stroke-(stroke/100)*(parseInt(prct)));
    }

    // Alerts messages
    showAlert(title,message,textbutton) {
        let alert = this.alertCtrl.create({
            title: title,
            message: message,
            buttons: [textbutton]
        });
        alert.present();
    }

    // Toast message for errors
    showToast() {
        let toast = this.toastCtrl.create({
            message: 'Error, si us plau torna-ho a provar',
            duration: 3000,
            position: 'bottom'
        });
        toast.present();
    }

    // Show loading message
    showLoading() {
        if(!this.loading){
            this.loading = this.loadingCtrl.create({
                spinner: 'crescent',
                content: 'Carregant dades ...'
            });
            this.loading.present();
        } else {
            this.loading.present();
        }
    }
    // Hide loading message
    dismissLoading() {
        if(this.loading){
            this.loading.dismiss();
            this.loading = null;
        }
    }
    // Show login message
    showLogin() {
        if(!this.loadingLogin){
            this.loadingLogin = this.loadingCtrl.create({
                spinner: 'crescent',
                content: 'Iniciant ...'
            });
            this.loadingLogin.present();
        } else {
            this.loadingLogin.present();
        }
    }
    // Hide login message
    dismissLogin() {
        if(this.loadingLogin){
            this.loadingLogin.dismiss();
            this.loadingLogin = null;
        }
    }

    // Moment functions
    getDay () {
        return moment().format("D");
    }
    getMonth () {
        return moment().format("MMMM");
    }
    getMonthShort () {
        let month = moment().format("MMM");
        return month.substr(0,3); // without the unexplicable final dot
    }
    getDate () {
        return moment().format("DD/MM/YYYY");
    }
    getHour () {
        return moment().format("HH:mm:ss");
    }
    getDateHour () {
        return moment().format("DD/MM/YYYY HH:mm:ss");
    }

    // Numeral funcions
    setThousands ($string) {
        return numeral($string).format('0,0');
    }
    setPercentage ($value1,$value2) {
        return numeral($value1/($value1+$value2)).format('0%');
    }

}